# -*- coding: utf-8 -*-
# Copyright (c) 2015-2022, Exa Analytics Development Team
# Distributed under the terms of the Apache License 2.0
"""
Cell Packing Utilities
########################
"""
#def cubic_cell_volume(mass, density):
#    """
#    Args:
#        mass (float): Total mass of all atoms (in atomic units)
#        density (float): Desired density (in g/cm^3)
#
#    Returns:
#        a (float): Cubic unit cell dimension (in atomic units)
#    """
#    return mass*1.66054/density
